@@ -8,12 +8,8 @@ const baseRule = {
     use: {
         loader: "babel-loader",
         options: {
-            presets: [
-                "@babel/preset-env"
-            ],
-            plugins: [
-                "@babel/plugin-syntax-dynamic-import"
-            ]
+            presets: ["@babel/preset-env"],
+            plugins: ["@babel/plugin-syntax-dynamic-import", "@babel/plugin-proposal-optional-chaining"]
         }
     }
 }
